@@ -1,9 +1,9 @@
 """Test testid plugin."""
+import io
 import os.path
 import pickle
 
 from nose2 import session
-import six
 from nose2.events import ReportTestEvent
 from nose2.plugins import testid
 from nose2.tests._common import (
@@ -26,8 +26,8 @@ class UnitTestTestId(TestCase):
     _RUN_IN_TEMP = True
 
     def setUp(self):
-        super(UnitTestTestId, self).setUp()
-        self.stream = six.StringIO()
+        super().setUp()
+        self.stream = io.StringIO()
         self.session = session.Session()
         self.plugin = testid.TestId(session=self.session)
 
@@ -46,12 +46,12 @@ class UnitTestTestId(TestCase):
             try:
                 val = getattr(plug, name)
             except AttributeError:
-                self.fail("TestId instance doesn't have attribute %s" % (name,))
+                self.fail(f"TestId instance doesn't have attribute {name}")
             self.assertEqual(
                 val,
                 exp_val,
-                "Attribute %s should have value "
-                "'%s', but has value %s" % (name, exp_val, val),
+                "Attribute {} should have value "
+                "'{}', but has value {}".format(name, exp_val, val),
             )
 
     def test_start_test(self):
